@@ -3,6 +3,7 @@ package decoders
 import (
 	"bytes"
 	"encoding/base64"
+	"unicode"
 
 	"github.com/trufflesecurity/trufflehog/v3/pkg/pb/detectorspb"
 	"github.com/trufflesecurity/trufflehog/v3/pkg/sources"
@@ -33,15 +34,12 @@ func (d *Base64) FromChunk(chunk *sources.Chunk) *DecodableChunk {
 
 	for _, str := range encodedSubstrings {
 		dec, err := base64.StdEncoding.DecodeString(str)
-		if err == nil {
-			if len(dec) > 0 {
-				decodedSubstrings[str] = dec
-			}
-			continue
+		if err == nil && len(dec) > 0 && isASCII(dec) {
+			decodedSubstrings[str] = dec
 		}
 
 		dec, err = base64.RawURLEncoding.DecodeString(str)
-		if err == nil && len(dec) > 0 {
+		if err == nil && len(dec) > 0 && isASCII(dec) {
 			decodedSubstrings[str] = dec
 		}
 	}
@@ -69,6 +67,15 @@ func (d *Base64) FromChunk(chunk *sources.Chunk) *DecodableChunk {
 	return nil
 }
 
+func isASCII(b []byte) bool {
+	for i := 0; i < len(b); i++ {
+		if b[i] > unicode.MaxASCII {
+			return false
+		}
+	}
+	return true
+}
+
 func getSubstringsOfCharacterSet(data []byte, threshold int, charsetMapping [128]bool, endChars string) []string {
 	if len(data) == 0 {
 		return nil
