@@ -48,9 +48,8 @@ set PATH=%PATH%;C:\Program Files\nodejs\;C:\Program Files\Git\cmd`,
 
 	for _, test := range tests {
 		t.Run(test.name, func(t *testing.T) {
-			chunkSpecificDetectors := make(map[ahocorasick.DetectorKey]detectors.Detector, 2)
-			ahoCorasickCore.FindDetectorMatches(test.input, chunkSpecificDetectors)
-			if len(chunkSpecificDetectors) == 0 {
+			matches := ahoCorasickCore.FindDetectorMatches([]byte(test.input))
+			if len(matches) == 0 {
 				t.Errorf("keywords '%v' not matched by: %s", d.Keywords(), test.input)
 				return
 			}
